Index: webrtc/media/base/videoengine_unittest.h |
diff --git a/webrtc/media/base/videoengine_unittest.h b/webrtc/media/base/videoengine_unittest.h |
index 2b4858e10f0cb466ce87e220016d1425d5672532..62bb1254164d393feb80b063a90a42fe20a29b6c 100644 |
--- a/webrtc/media/base/videoengine_unittest.h |
+++ b/webrtc/media/base/videoengine_unittest.h |
@@ -126,7 +126,7 @@ class VideoMediaChannelTest : public testing::Test, |
cricket::VideoFormat::FpsToInterval(30), |
cricket::FOURCC_I420); |
EXPECT_EQ(cricket::CS_RUNNING, video_capturer_->Start(format)); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, video_capturer_.get())); |
+ channel_->SetSource(kSsrc, video_capturer_.get()); |
} |
virtual cricket::FakeVideoCapturer* CreateFakeVideoCapturer() { |
@@ -163,7 +163,7 @@ class VideoMediaChannelTest : public testing::Test, |
cricket::FOURCC_I420); |
EXPECT_EQ(cricket::CS_RUNNING, video_capturer_2_->Start(format)); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc + 2, video_capturer_2_.get())); |
+ channel_->SetSource(kSsrc + 2, video_capturer_2_.get()); |
} |
virtual void TearDown() { |
channel_.reset(); |
@@ -374,7 +374,7 @@ class VideoMediaChannelTest : public testing::Test, |
// Test that SetSend works. |
void SetSend() { |
EXPECT_FALSE(channel_->sending()); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, video_capturer_.get())); |
+ channel_->SetSource(kSsrc, video_capturer_.get()); |
EXPECT_TRUE(SetOneCodec(DefaultCodec())); |
EXPECT_FALSE(channel_->sending()); |
EXPECT_TRUE(SetSend(true)); |
@@ -568,7 +568,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_EQ(cricket::CS_RUNNING, capturer->Start(format)); |
EXPECT_TRUE(channel_->AddSendStream( |
cricket::StreamParams::CreateLegacy(5678))); |
- EXPECT_TRUE(channel_->SetCapturer(5678, capturer.get())); |
+ channel_->SetSource(5678, capturer.get()); |
EXPECT_TRUE(channel_->AddRecvStream( |
cricket::StreamParams::CreateLegacy(5678))); |
EXPECT_TRUE(channel_->SetSink(5678, &renderer2)); |
@@ -604,7 +604,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_EQ(kTestWidth, info.senders[1].send_frame_width); |
EXPECT_EQ(kTestHeight, info.senders[1].send_frame_height); |
// The capturer must be unregistered here as it runs out of it's scope next. |
- EXPECT_TRUE(channel_->SetCapturer(5678, NULL)); |
+ channel_->SetSource(5678, NULL); |
} |
// Test that we can set the bandwidth. |
@@ -641,7 +641,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_TRUE(SetDefaultCodec()); |
EXPECT_TRUE(channel_->AddSendStream( |
cricket::StreamParams::CreateLegacy(999))); |
- EXPECT_TRUE(channel_->SetCapturer(999u, video_capturer_.get())); |
+ channel_->SetSource(999u, video_capturer_.get()); |
EXPECT_TRUE(SetSend(true)); |
EXPECT_TRUE(WaitAndSendFrame(0)); |
EXPECT_TRUE_WAIT(NumRtpPackets() > 0, kTimeout); |
@@ -707,7 +707,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_TRUE(channel_->AddSendStream( |
cricket::StreamParams::CreateLegacy(789u))); |
- EXPECT_TRUE(channel_->SetCapturer(789u, video_capturer_.get())); |
+ channel_->SetSource(789u, video_capturer_.get()); |
EXPECT_EQ(rtp_packets, NumRtpPackets()); |
// Wait 30ms to guarantee the engine does not drop the frame. |
EXPECT_TRUE(WaitAndSendFrame(30)); |
@@ -790,7 +790,7 @@ class VideoMediaChannelTest : public testing::Test, |
int captured_frames = 1; |
for (int iterations = 0; iterations < 2; ++iterations) { |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, capturer.get())); |
+ channel_->SetSource(kSsrc, capturer.get()); |
rtc::Thread::Current()->ProcessMessages(time_between_send); |
EXPECT_TRUE(capturer->CaptureCustomFrame(format.width, format.height, |
cricket::FOURCC_I420)); |
@@ -805,7 +805,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_EQ(format.height, renderer_.height()); |
captured_frames = renderer_.num_rendered_frames() + 1; |
EXPECT_FALSE(renderer_.black_frame()); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
// Make sure a black frame is generated within the specified timeout. |
// The black frame should be the resolution of the previous frame to |
// prevent expensive encoder reconfigurations. |
@@ -840,13 +840,13 @@ class VideoMediaChannelTest : public testing::Test, |
// tightly. |
rtc::Thread::Current()->ProcessMessages(30); |
// Remove the capturer. |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
// Wait for one black frame for removing the capturer. |
EXPECT_FRAME_WAIT(2, 640, 400, kTimeout); |
// No capturer was added, so this RemoveCapturer should |
- // fail. |
- EXPECT_FALSE(channel_->SetCapturer(kSsrc, NULL)); |
+ // be a NOP. |
+ channel_->SetSource(kSsrc, NULL); |
rtc::Thread::Current()->ProcessMessages(300); |
// Verify no more frames were sent. |
EXPECT_EQ(2, renderer_.num_rendered_frames()); |
@@ -888,11 +888,11 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_EQ(cricket::CS_RUNNING, capturer2->Start(capture_format)); |
// State for all the streams. |
EXPECT_TRUE(SetOneCodec(DefaultCodec())); |
// A limitation in the lmi implementation requires that SetCapturer() is |
// called after SetOneCodec(). |
// TODO(hellner): this seems like an unnecessary constraint, fix it. |
- EXPECT_TRUE(channel_->SetCapturer(1, capturer1.get())); |
- EXPECT_TRUE(channel_->SetCapturer(2, capturer2.get())); |
+ channel_->SetSource(1, capturer1.get()); |
+ channel_->SetSource(2, capturer2.get()); |
EXPECT_TRUE(SetSend(true)); |
// Test capturer associated with engine. |
const int kTestWidth = 160; |
@@ -907,13 +907,13 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_FRAME_ON_RENDERER_WAIT( |
renderer2, 1, kTestWidth, kTestHeight, kTimeout); |
// Successfully remove the capturer. |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
// Fail to re-remove the capturer. |
- EXPECT_FALSE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
// The capturers must be unregistered here as it runs out of it's scope |
// next. |
- EXPECT_TRUE(channel_->SetCapturer(1, NULL)); |
- EXPECT_TRUE(channel_->SetCapturer(2, NULL)); |
+ channel_->SetSource(1, NULL); |
+ channel_->SetSource(2, NULL); |
} |
void HighAspectHighHeightCapturer() { |
@@ -946,13 +946,13 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_EQ(cricket::CS_RUNNING, capturer->Start(capture_format)); |
// Capture frame to not get same frame timestamps as previous capturer. |
capturer->CaptureFrame(); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, capturer.get())); |
+ channel_->SetSource(kSsrc, capturer.get()); |
EXPECT_TRUE(rtc::Thread::Current()->ProcessMessages(30)); |
EXPECT_TRUE(capturer->CaptureCustomFrame(kWidth, kHeight, |
cricket::FOURCC_ARGB)); |
EXPECT_GT_FRAME_ON_RENDERER_WAIT( |
renderer, 2, kScaledWidth, kScaledHeight, kTimeout); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
} |
// Tests that we can adapt video resolution with 16:10 aspect ratio properly. |
@@ -1072,7 +1072,7 @@ class VideoMediaChannelTest : public testing::Test, |
640, 480, |
cricket::VideoFormat::FpsToInterval(30), |
cricket::FOURCC_I420)); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, &video_capturer)); |
+ channel_->SetSource(kSsrc, &video_capturer); |
EXPECT_TRUE(SetSend(true)); |
EXPECT_TRUE(channel_->SetSink(kDefaultReceiveSsrc, &renderer_)); |
EXPECT_EQ(0, renderer_.num_rendered_frames()); |
@@ -1111,7 +1111,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_TRUE(channel_->SetVideoSend(kSsrc, true, nullptr)); |
// Test that muting an invalid stream fails. |
EXPECT_FALSE(channel_->SetVideoSend(kSsrc+1, false, nullptr)); |
- EXPECT_TRUE(channel_->SetCapturer(kSsrc, NULL)); |
+ channel_->SetSource(kSsrc, NULL); |
} |
// Test that multiple send streams can be created and deleted properly. |
@@ -1172,7 +1172,7 @@ class VideoMediaChannelTest : public testing::Test, |
EXPECT_FALSE(channel_->AddRecvStream( |
cricket::StreamParams::CreateLegacy(new_ssrc))); |
- EXPECT_TRUE(channel_->SetCapturer(new_ssrc, video_capturer_.get())); |
+ channel_->SetSource(new_ssrc, video_capturer_.get()); |
SendAndReceive(codec); |
EXPECT_TRUE(channel_->RemoveSendStream(new_ssrc)); |
@@ -888,11 +888,11 @@ class VideoMediaChannelTest : public testing::Test, |
// State for all the streams. |
EXPECT_TRUE(SetOneCodec(DefaultCodec())); |
- // A limitation in the lmi implementation requires that SetCapturer() is |
+ // A limitation in the lmi implementation requires that SetSource() is |
// called after SetOneCodec(). |
// TODO(hellner): this seems like an unnecessary constraint, fix it. |